==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/ar/admin/hardware/form.php <==
<?php

return array(
	'bulk_delete'		=> 'تاكيد إجراء حذف للاُصول المحددة',
  'bulk_delete_help'	=> 'الرجاء مراجعة الأصول المحددة للحذف أدناه. بمجرد الحذف، يمكن استعادة هذه الأصول، لكنها لن تكون مرتبطة مع أي من المستخدمين اللذين تم اخراج الأصول لهم من قبل.',
  'bulk_delete_warn'	=> 'أنت على وشك حذف :asset_count من الأصول.',
	'bulk_update'		=> 'تحديث للأصول المحددة',
	'bulk_update_help'	=> 'يتيح لك هذا النموذج تحديث عدة أصول دفعة واحدة. قم بملء الحقول التي تحتاج إلى تغييرها. ستظل أية حقول فارغة بدون تغيير. ',
	'bulk_update_warn'	=> 'أنت على وشك تعديل خصائص :asset_count من الأصول.',
    'checkedout_to'		=> 'تم الاخراج إلى',
    'checkout_date'		=> 'تاريخ الاخراج',
    'checkin_date'		=> 'تاريخ الادخال',
    'checkout_to'		=> 'اخراج إلى',
    'cost'				=> 'تكلفة الشراء',
    'create'			=> 'إنشاء أصل',
    'date'				=> 'تاريخ الشراء',
    'depreciation'	    => 'الاستهلاك',
    'depreciates_on'	=> 'ينتهي الاستهلاك في',
    'default_location'	=> 'الموقع الافتراضي',
    'eol_date'			=> 'تاريخ نهاية العمر',
    'eol_rate'			=> 'معدل انتهاء العمر',
    'expected_checkin'  => 'تاريخ الادخال المتوقع',
    'expires'			=> 'انتهاء الصلاحية',
    'fully_depreciated'	=> 'مستهلك بالكامل',
    'help_checkout'		=> 'إذا كنت ترغب في اخراج هذا الأصل فورا، فحدد "جاهز للتوزيع" من قائمة الحالة أعلاه. ',
    'mac_address'		=> 'عنوان ماك (MAC)',
    'manufacturer'		=> 'الصانع',
    'model'				=> 'الموديل',
    'months'			=> 'أشهر',
    'name'				=> 'اسم الأصل',
    'notes'				=> 'مُلاحظات',
    'order'				=> 'رقم طلب الشراء',
    'qr'				=> 'رمز الاستجابة السريعة QR',
    'requestable'		=> 'يمكن للمستخدمين طلب هذا الأصل',
    'select_statustype'	=> 'حدد نوع الحالة',
    'serial'			=> 'التسلسل',
    'status'			=> 'الحالة',
    'tag'				=> 'ترميز الأصل',
    'update'			=> 'تحديث الأصل',
    'warranty'			=> 'الضمان',
		'warranty_expires'		=> 'انتهاء مدة صلاحية الضمان',
    'years'				=> 'سنوات',
)
;

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/ar/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'تاكيد إجراء حذف للاُصول المحددة',
  'bulk_delete_help'	=> 'الرجاء مراجعة الأصول المحددة للحذف أدناه. بمجرد الحذف، يمكن استعادة هذه الأصول، لكنها لن تكون مرتبطة مع أي من المستخدمين اللذين تم اخراج الأصول لهم من قبل.',
  'bulk_delete_warn'	=> 'أنت على وشك حذف :asset_count من الأصول.',
    'bulk_update'		=> 'تحديث للأصول المحددة',
    'bulk_update_help'	=> 'يتيح لك هذا النموذج تحديث عدة أصول دفعة واحدة. قم بملء الحقول التي تحتاج إلى تغييرها. ستظل أية حقول فارغة بدون تغيير. ',
    'bulk_update_warn'	=> 'أنت على وشك تعديل خصائص :asset_count من الأصول.',
    'checkedout_to'		=> 'تم الاخراج إلى',
    'checkout_date'		=> 'تاريخ الاخراج',
    'checkin_date'		=> 'تاريخ الادخال',
    'checkout_to'		=> 'اخراج إلى',
    'cost'				=> 'تكلفة الشراء',
    'create'			=> 'إنشاء أصل',
    'date'				=> 'تاريخ الشراء',
    'depreciation'	    => 'الاستهلاك',
    'depreciates_on'	=> 'ينتهي الاستهلاك في',
    'default_location'	=> 'الموقع الافتراضي',
    'eol_date'			=> 'تاريخ نهاية العمر',
    'eol_rate'			=> 'معدل انتهاء العمر',
    'expected_checkin'  => 'تاريخ الادخال المتوقع',
    'expires'			=> 'انتهاء الصلاحية',
    'fully_depreciated'	=> 'مستهلك بالكامل',
    'help_checkout'		=> 'إذا كنت ترغب في اخراج هذا الأصل فورا، فحدد "جاهز للتوزيع" من قائمة الحالة أعلاه. ',
    'mac_address'		=> 'عنوان ماك (MAC)',
    'manufacturer'		=> 'الصانع',
    'model'				=> 'الموديل',
    'months'			=> 'أشهر',
    'name'				=> 'اسم الأصل',
    'notes'				=> 'مُلاحظات',
    'order'				=> 'رقم طلب الشراء',
    'qr'				=> 'رمز الاستجابة السريعة QR',
    'requestable'		=> 'يمكن للمستخدمين طلب هذا الأصل',
    'select_statustype'	=> 'حدد نوع الحالة',
    'serial'			=> 'التسلسل',
    'status'			=> 'الحالة',
    'tag'				=> 'ترميز الأصل',
    'update'			=> 'تحديث الأصل',
    'warranty'			=> 'الضمان',
        'warranty_expires'		=> 'انتهاء مدة صلاحية الضمان',
    'years'				=> 'سنوات',
    'asset_location' => 'Update Asset Location',
    'asset_location_update_default_current' => 'Update default location AND actual location',
    'asset_location_update_default' => 'Update only default location',
    'asset_not_deployable' => 'That asset status is not deployable. This asset cannot be checked out.',
    'asset_deployable' => 'That status is deployable. This asset can be checked out.',
    'processing_spinner' => 'Processing...',
];
